@@ -52,7 +52,7 @@ for project in Project.NAME.value:
                 tenant_id=project_config["tenant_id"],
                 client_id=project_config["client_id"],
                 secret_name=project_config["secret_name"],
-                token_url=project_config["secret_name"],
+                token_url=project_config["token_url"],
                 scopes=project_config["scopes"],
             )
         else:
