@@ -54,8 +54,10 @@ def final_string_generator():
 
     for i in function_project_mapping:
         function_name, project_name = i.split("@")
+        print(f"Processing function :{function_name} in project :{project_name}")
         deployment_boolean = check_deployment(function_name, project_name)
         file_path_changed_boolean = file_path_changed("functions/" + function_name)
+        file_path_changed_boolean = file_path_changed_boolean.rstrip()
         if file_path_changed_boolean == "True" or deployment_boolean == "True":
             filtered_list.append('"' + i + '"')
     if not filtered_list:
