@@ -3,10 +3,11 @@ import shutil
 import time
 from pathlib import Path
 from tempfile import TemporaryDirectory
-from typing import Optional
+from typing import Any, Optional, Union
 
 from cognite.client import CogniteClient
 from cognite.experimental import CogniteClient as ExperimentalClient
+from cognite.experimental.data_classes import Function
 
 from cognite.airworkflow.constants import AUTHENTICATION, COGNITE_CLIENT_NAME
 
@@ -52,21 +53,22 @@ def does_function_exist(
     return False
 
 
-def await_function_deployment(client: ExperimentalClient, function_id: int, max_wait: int) -> bool:
+def await_function_deployment(client: ExperimentalClient, function: Function, max_wait: int) -> Union[bool, Any]:
     t_end = time.time() + max_wait
+    old_id = function.id
     while time.time() < t_end:
-        function = client.functions.retrieve(id=function_id)
+        function = client.functions.retrieve(id=function.id)
         if function is not None:
-            print(f"Function status {function.status} - Function id {function_id}")
+            print(f"Function status {function.status} - Function id {function.id}", flush=True)
             if function.status == "Ready":
-                return True
+                return True, function
             if function.status == "Failed":
-                return False
+                return False, function
         else:
-            print(f"API returns None for Function id {function_id}")
+            print(f"API returns None for Function id {old_id}", flush=True)
         time.sleep(5.0)
 
-    return False
+    return False, None
 
 
 def experimental_client(project: str) -> ExperimentalClient:
